@@ -22,7 +22,9 @@
 #include "gp-applet-frame.h"
 #include "gp-applet-manager.h"
 #include "libgnome-panel/gp-applet-info-private.h"
+#include "libgnome-panel/gp-initial-setup-dialog-private.h"
 #include "libgnome-panel/gp-module-private.h"
+#include "panel-lockdown.h"
 
 struct _GpAppletManager
 {
@@ -34,6 +36,37 @@ struct _GpAppletManager
 
 G_DEFINE_TYPE (GpAppletManager, gp_applet_manager, PANEL_TYPE_APPLETS_MANAGER)
 
+static GVariant *
+get_initial_settings (PanelAppletFrameActivating *frame_act)
+{
+  gchar *path;
+  GSettings *settings;
+  GVariant *initial_settings;
+
+  path = panel_applet_frame_activating_get_initial_settings_path (frame_act);
+  settings = g_settings_new_with_path ("org.gnome.gnome-panel.applet.initial-settings", path);
+  g_free (path);
+
+  initial_settings = g_settings_get_user_value (settings, "settings");
+  g_object_unref (settings);
+
+  return initial_settings;
+}
+
+static void
+remove_initial_settings (PanelAppletFrameActivating *frame_act)
+{
+  gchar *path;
+  GSettings *settings;
+
+  path = panel_applet_frame_activating_get_initial_settings_path (frame_act);
+  settings = g_settings_new_with_path ("org.gnome.gnome-panel.applet.initial-settings", path);
+  g_free (path);
+
+  g_settings_reset (settings, "settings");
+  g_object_unref (settings);
+}
+
 static void
 get_applet_infos (GpAppletManager *manager,
                   const gchar     *id,
@@ -190,6 +223,7 @@ gp_applet_manager_load_applet (PanelAppletsManager        *manager,
   PanelOrientation panel_orientation;
   GtkOrientation orientation;
   GtkPositionType position;
+  GVariant *initial_settings;
   GError *error;
   GpApplet *applet;
   GpAppletFrame *frame;
@@ -238,8 +272,13 @@ gp_applet_manager_load_applet (PanelAppletsManager        *manager,
         break;
     }
 
+  initial_settings = get_initial_settings (frame_act);
+
   error = NULL;
-  applet = gp_module_applet_new (module, applet_id, settings_path, &error);
+  applet = gp_module_applet_new (module, applet_id, settings_path,
+                                 initial_settings, &error);
+
+  g_clear_pointer (&initial_settings, g_variant_unref);
   g_free (settings_path);
 
   if (!applet)
@@ -250,6 +289,8 @@ gp_applet_manager_load_applet (PanelAppletsManager        *manager,
       return FALSE;
     }
 
+  remove_initial_settings (frame_act);
+
   gp_applet_set_locked_down (applet, locked_down);
   gp_applet_set_orientation (applet, orientation);
   gp_applet_set_position (applet, position);
@@ -312,6 +353,106 @@ gp_applet_manager_get_new_iid (PanelAppletsManager *manager,
   return new_iid;
 }
 
+static gboolean
+gp_applet_manager_open_initial_setup_dialog (PanelAppletsManager    *manager,
+                                             const gchar            *iid,
+                                             GtkWindow              *parent,
+                                             GpInitialSetupCallback  callback,
+                                             gpointer                user_data,
+                                             GDestroyNotify          free_func)
+{
+  GpAppletManager *applet_manager;
+  const gchar *applet_id;
+  gchar *module_id;
+  GpModule *module;
+  GpAppletInfo *info;
+  GpInitialSetupDialog *dialog;
+
+  g_return_val_if_fail (iid != NULL, FALSE);
+
+  applet_manager = GP_APPLET_MANAGER (manager);
+
+  applet_id = g_strrstr (iid, "::");
+  if (!applet_id)
+    return FALSE;
+
+  module_id = g_strndup (iid, strlen (iid) - strlen (applet_id));
+  module = g_hash_table_lookup (applet_manager->modules, module_id);
+  g_free (module_id);
+
+  if (!module)
+    return FALSE;
+
+  applet_id += 2;
+  info = gp_module_get_applet_info (module, applet_id, NULL);
+
+  if (!info || !info->initial_setup_dialog_func)
+    return FALSE;
+
+  dialog = gp_initital_setup_dialog_new ();
+  gp_initital_setup_dialog_add_callback (dialog, callback, user_data, free_func);
+
+  info->initial_setup_dialog_func (dialog);
+
+  if (parent)
+    {
+      gtk_window_set_transient_for (GTK_WINDOW (dialog), parent);
+      gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
+    }
+  else
+    {
+      gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
+    }
+
+
+  gtk_widget_show (GTK_WIDGET (dialog));
+
+  return TRUE;
+}
+
+static GtkWidget *
+gp_applet_manager_get_standalone_menu (PanelAppletsManager *manager)
+{
+  GpAppletManager *applet_manager;
+  GSettings *general_settings;
+  gboolean enable_tooltips;
+  gboolean locked_down;
+  guint menu_icon_size;
+  GList *modules;
+  GList *l;
+  GtkWidget *menu;
+
+  applet_manager = GP_APPLET_MANAGER (manager);
+
+  general_settings = g_settings_new ("org.gnome.gnome-panel.general");
+
+  enable_tooltips = g_settings_get_boolean (general_settings, "enable-tooltips");
+  locked_down = panel_lockdown_get_panels_locked_down_s ();
+  menu_icon_size = g_settings_get_enum (general_settings, "menu-icon-size");
+
+  g_object_unref (general_settings);
+
+  modules = g_hash_table_get_values (applet_manager->modules);
+  menu = NULL;
+
+  for (l = modules; l != NULL; l = l->next)
+    {
+      GpModule *module;
+
+      module = GP_MODULE (l->data);
+
+      menu = gp_module_get_standalone_menu (module, enable_tooltips,
+                                            locked_down, menu_icon_size);
+
+      if (menu != NULL)
+        break;
+    }
+
+  g_list_free (modules);
+
+  return menu;
+}
+
 static void
 gp_applet_manager_class_init (GpAppletManagerClass *manager_class)
 {
@@ -330,6 +471,8 @@ gp_applet_manager_class_init (GpAppletManagerClass *manager_class)
   applets_manager_class->load_applet = gp_applet_manager_load_applet;
   applets_manager_class->get_applet_widget = gp_applet_manager_get_applet_widget;
   applets_manager_class->get_new_iid = gp_applet_manager_get_new_iid;
+  applets_manager_class->open_initial_setup_dialog = gp_applet_manager_open_initial_setup_dialog;
+  applets_manager_class->get_standalone_menu = gp_applet_manager_get_standalone_menu;
 }
 
 static void
