@@ -21,10 +21,8 @@
 #include "panel.h"
 #include "panel-bindings.h"
 #include "panel-util.h"
-#include "panel-marshal.h"
 #include "panel-typebuiltins.h"
 #include "panel-applet-frame.h"
-#include "panel-globals.h"
 #include "panel-lockdown.h"
 
 typedef enum {
@@ -48,6 +46,8 @@ enum {
 
 static guint panel_widget_signals [LAST_SIGNAL] = {0};
 
+static GSList *panels = NULL;
+
 /*define for some debug output*/
 #undef PANEL_WIDGET_DEBUG
 
@@ -275,7 +275,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, applet_move),
                               NULL,
                               NULL, 
-                              g_cclosure_marshal_VOID__POINTER,
+                              NULL,
                               G_TYPE_NONE,
                               1,
                               G_TYPE_POINTER); 
@@ -287,7 +287,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, applet_added),
                               NULL,
                               NULL, 
-                              g_cclosure_marshal_VOID__POINTER,
+                              NULL,
                               G_TYPE_NONE,
                               1,
                               G_TYPE_POINTER); 
@@ -299,7 +299,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, applet_removed),
                               NULL,
                               NULL, 
-                              g_cclosure_marshal_VOID__POINTER,
+                              NULL,
                               G_TYPE_NONE,
                               1,
                               G_TYPE_POINTER); 
@@ -311,7 +311,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, push_move),
                               NULL,
                               NULL,
-                              g_cclosure_marshal_VOID__ENUM,
+                              NULL,
                               G_TYPE_NONE,
                               1,
                               GTK_TYPE_DIRECTION_TYPE);
@@ -323,7 +323,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, switch_move),
                               NULL,
                               NULL,
-                              g_cclosure_marshal_VOID__ENUM,
+                              NULL,
                               G_TYPE_NONE,
                               1,
                               GTK_TYPE_DIRECTION_TYPE);
@@ -335,7 +335,7 @@ panel_widget_class_init (PanelWidgetClass *class)
 			      G_STRUCT_OFFSET (PanelWidgetClass, tab_move),
                               NULL,
                               NULL,
-                              g_cclosure_marshal_VOID__BOOLEAN,
+                              NULL,
                               G_TYPE_NONE,
                               1,
                               G_TYPE_BOOLEAN);
@@ -347,7 +347,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, end_move),
                               NULL,
                               NULL,
-                              g_cclosure_marshal_VOID__VOID,
+                              NULL,
                               G_TYPE_NONE,
                               0);
 
@@ -1691,21 +1691,19 @@ panel_widget_applet_drag_start (PanelWidget *panel,
 	window = gtk_widget_get_window (applet);
 	if (window) {
 		GdkGrabStatus  status;
-		GdkCursor     *fleur_cursor;
 		GdkDisplay    *display;
+		GdkCursor     *fleur_cursor;
 		GdkSeat       *seat;
 
-		fleur_cursor = gdk_cursor_new_for_display (gdk_display_get_default (),
-		                                           GDK_FLEUR);
-
-		display = gdk_window_get_display (window);
+		display = gdk_display_get_default ();
+		fleur_cursor = gdk_cursor_new_for_display (display, GDK_FLEUR);
 		seat = gdk_display_get_default_seat (display);
 
 		status = gdk_seat_grab (seat, window, GDK_SEAT_CAPABILITY_POINTER,
 		                        FALSE, fleur_cursor, NULL, NULL, NULL);
 
 		g_object_unref (fleur_cursor);
-		gdk_flush ();
+		gdk_display_flush (display);
 
 		if (status != GDK_GRAB_SUCCESS) {
 			g_warning (G_STRLOC ": failed to grab pointer (errorcode: %d)",
@@ -1733,7 +1731,7 @@ panel_widget_applet_drag_end (PanelWidget *panel)
 	gtk_grab_remove (panel->currently_dragged_applet->applet);
 	panel_widget_applet_drag_end_no_grab (panel);
 	panel_toplevel_pop_autohide_disabler (panel->toplevel);
-	gdk_flush ();
+	gdk_display_flush (display);
 }
 
 /*get pos of the cursor location in panel coordinates*/
@@ -2314,6 +2312,7 @@ panel_widget_reparent (PanelWidget         *old_panel,
 	AppletData *ad;
 	GtkWidget *focus_widget = NULL;
 	AppletInfo* info;
+	GdkDisplay *display;
 
 	g_return_val_if_fail(PANEL_IS_WIDGET(old_panel), FALSE);
 	g_return_val_if_fail(PANEL_IS_WIDGET(new_panel), FALSE);
@@ -2364,7 +2363,8 @@ panel_widget_reparent (PanelWidget         *old_panel,
 	}
  	gtk_window_present (GTK_WINDOW (new_panel->toplevel));
 
-	gdk_flush();
+	display = gdk_display_get_default ();
+	gdk_display_flush (display);
 
 	emit_applet_moved (new_panel, ad);
 
@@ -2659,3 +2659,8 @@ panel_widget_register_open_dialog (PanelWidget *panel,
 				 panel,
 				 G_CONNECT_SWAPPED);
 }
+
+GSList *panel_widget_get_panels (void)
+{
+  return panels;
+}
