@@ -26,7 +26,6 @@ struct _PanelAppletFactory {
 
 	gchar     *factory_id;
 	guint      n_applets;
-	gboolean   out_of_process;
 	GType      applet_type;
 	GClosure  *closure;
 
@@ -121,7 +120,6 @@ panel_applet_factory_applet_removed (PanelAppletFactory *factory,
 
 PanelAppletFactory *
 panel_applet_factory_new (const gchar *factory_id,
-                          gboolean     out_of_process,
 			  GType        applet_type,
 			  GClosure    *closure)
 {
@@ -129,7 +127,6 @@ panel_applet_factory_new (const gchar *factory_id,
 
 	factory = PANEL_APPLET_FACTORY (g_object_new (PANEL_TYPE_APPLET_FACTORY, NULL));
 	factory->factory_id = g_strdup (factory_id);
-	factory->out_of_process = out_of_process;
 	factory->applet_type = applet_type;
 	factory->closure = g_closure_ref (closure);
 
@@ -152,28 +149,24 @@ set_applet_constructor_properties (GObject  *applet,
 
 	g_variant_iter_init (&iter, props);
 	while (g_variant_iter_loop (&iter, "{sv}", &key, &value)) {
-		switch (g_variant_classify (value)) {
-		case G_VARIANT_CLASS_UINT32: {
+		GVariantClass variant_class;
+
+		variant_class = g_variant_classify (value);
+
+		if (variant_class == G_VARIANT_CLASS_UINT32) {
 			guint32 v = g_variant_get_uint32 (value);
 
 			g_object_set (applet, key, v, NULL);
-		}
-			break;
-		case G_VARIANT_CLASS_STRING: {
+		} else if (variant_class == G_VARIANT_CLASS_STRING) {
 			const gchar *v = g_variant_get_string (value, NULL);
 
 			g_object_set (applet, key, v, NULL);
-		}
-			break;
-		case G_VARIANT_CLASS_BOOLEAN: {
+		} else if (variant_class == G_VARIANT_CLASS_BOOLEAN) {
 			gboolean v = g_variant_get_boolean (value);
 
 			g_object_set (applet, key, v, NULL);
-		}
-			break;
-		default:
+		} else {
 			g_assert_not_reached ();
-			break;
 		}
 	}
 }
@@ -187,18 +180,14 @@ panel_applet_factory_get_applet (PanelAppletFactory    *factory,
 {
 	GObject     *applet;
 	const gchar *applet_id;
-	gint         screen_num;
 	GVariant    *props;
 	GVariant    *return_value;
-	GdkScreen   *screen;
-	guint32      xid;
 	guint32      uid;
 	const gchar *object_path;
 
-	g_variant_get (parameters, "(&si@a{sv})", &applet_id, &screen_num, &props);
+	g_variant_get (parameters, "(&s@a{sv})", &applet_id, &props);
 
 	applet = g_object_new (factory->applet_type,
-	                       "out-of-process", factory->out_of_process,
 			       "id", applet_id,
 			       "connection", connection,
 			       "closure", factory->closure,
@@ -209,22 +198,13 @@ panel_applet_factory_get_applet (PanelAppletFactory    *factory,
 	set_applet_constructor_properties (applet, props);
 	g_variant_unref (props);
 
-	screen = screen_num != -1 ?
-		gdk_display_get_screen (gdk_display_get_default (), screen_num) :
-		gdk_screen_get_default ();
-
-	xid = panel_applet_get_xid (PANEL_APPLET (applet), screen);
 	uid = factory->next_uid++;
 	object_path = panel_applet_get_object_path (PANEL_APPLET (applet));
 
 	g_hash_table_insert (factory->applets, GUINT_TO_POINTER (uid), applet);
 	g_object_set_data (applet, "uid", GUINT_TO_POINTER (uid));
 
-	return_value = g_variant_new ("(obuu)",
-	                              object_path,
-	                              factory->out_of_process,
-	                              xid,
-	                              uid);
+	return_value = g_variant_new ("(ou)", object_path, uid);
 
 	g_dbus_method_invocation_return_value (invocation, return_value);
 }
@@ -251,11 +231,8 @@ static const gchar introspection_xml[] =
 	    "<interface name='org.gnome.panel.applet.AppletFactory'>"
 	      "<method name='GetApplet'>"
 	        "<arg name='applet_id' type='s' direction='in'/>"
-	        "<arg name='screen' type='i' direction='in'/>"
 	        "<arg name='props' type='a{sv}' direction='in'/>"
 	        "<arg name='applet' type='o' direction='out'/>"
-	        "<arg name='out-of-process' type='b' direction='out'/>"
-	        "<arg name='xid' type='u' direction='out'/>"
 	        "<arg name='uid' type='u' direction='out'/>"
 	      "</method>"
 	    "</interface>"
