@@ -25,8 +25,6 @@
 
 G_BEGIN_DECLS
 
-guint32      panel_applet_get_xid           (PanelApplet *applet,
-                                             GdkScreen   *screen);
 const gchar *panel_applet_get_object_path   (PanelApplet *applet);
 GtkWidget   *panel_applet_get_applet_widget (const gchar *factory_id,
                                              guint        uid);
