@@ -476,3 +476,43 @@ gp_menu_utils_get_user_name (void)
 
   return user_name;
 }
+
+gchar *
+gp_menu_utils_get_applications_menu (void)
+{
+  const gchar *xdg_menu_prefx;
+
+  xdg_menu_prefx = g_getenv ("XDG_MENU_PREFIX");
+  if (!xdg_menu_prefx || *xdg_menu_prefx == '\0')
+    return g_strdup ("gnome-applications.menu");
+
+  return g_strdup_printf ("%sapplications.menu", xdg_menu_prefx);
+}
+
+void
+append_separator_if_needed (GtkMenu *menu)
+{
+  GList *children;
+  GList *last;
+  GtkWidget *item;
+
+  children = gtk_container_get_children (GTK_CONTAINER (menu));
+  last = g_list_last (children);
+
+  if (last == NULL)
+    return;
+
+  if (GTK_IS_SEPARATOR_MENU_ITEM (last->data))
+    {
+      g_list_free (children);
+      return;
+    }
+
+  g_list_free (children);
+
+  item = gtk_separator_menu_item_new ();
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+  gtk_widget_show (item);
+
+  gtk_widget_set_sensitive (item, FALSE);
+}
